@@ -1,5 +1,5 @@
 ## This file is part of the 'stringi' package for R.
-## Copyright (C) 2013-2015, Marek Gagolewski and Bartek Tartanus
+## Copyright (c) 2013-2019, Marek Gagolewski and other contributors.
 ## All rights reserved.
 ##
 ## Redistribution and use in source and binary forms, with or without
@@ -33,26 +33,30 @@
 #' Query Default Settings for \pkg{stringi}
 #'
 #' @description
-#' Presents current default settings used by the \pkg{ICU} library.
+#' Gives the current default settings used by the \pkg{ICU} library.
 #'
 #' @param short logical; whether or not the results should be given
 #' in a concise form; defaults to \code{TRUE}
 #'
-#' @return If \code{short=TRUE}, then a single string containing
-#' information on default character encoding, locale, and Unicode
+#' @return If \code{short==TRUE}, then a single string providing
+#' information on the default character encoding, locale, and Unicode
 #' as well as \pkg{ICU} version is returned.
 #'
-#' Otherwise, you a list with the following components is returned:
+#' Otherwise, a list with the following components is returned:
 #' \itemize{
-#' \item \code{Unicode.version} -- version of Unicode supported by the \pkg{ICU} library;
+#' \item \code{Unicode.version} -- version of Unicode supported
+#' by the \pkg{ICU} library;
 #' \item \code{ICU.version} -- \pkg{ICU} library version used;
 #' \item \code{Locale} -- contains information on default locale,
 #' as returned by \code{\link{stri_locale_info}};
-#' \item \code{Charset.internal} -- always \code{c("UTF-8", "UTF-16")};
-#' \item \code{Charset.native} -- information on default encoding,
+#' \item \code{Charset.internal} -- fixed at \code{c("UTF-8", "UTF-16")};
+#' \item \code{Charset.native} -- information on the default encoding,
 #' as returned by \code{\link{stri_enc_info}};
-#' \item \code{ICU.system} -- logical; indicates whether system \pkg{ICU} libs
-#' are used (\code{TRUE}) or if \pkg{ICU} was built together with \pkg{stringi}.
+#' \item \code{ICU.system} -- logical; \code{TRUE} indicates that
+#' the system \pkg{ICU} libs are used, otherwise \pkg{ICU} was built together
+#' with \pkg{stringi};
+#' \item \code{ICU.UTF8} -- logical; \code{TRUE} if the internal
+#' \code{U_CHARSET_IS_UTF8} flag is defined and set.
 #' }
 #'
 #' @export
@@ -62,7 +66,7 @@ stri_info <- function(short=FALSE) {
 
    info <- .Call(C_stri_info)
    if (info$Charset.native$Name.friendly != "UTF-8") {
-#       if (!info$Charset.native$CharSize.8bit)    # this should not cause problems, e.g. in the Big5 encoding
+#       if (!info$Charset.native$CharSize.8bit)    # this should not cause problems, e.g., in the Big5 encoding
 #          warning("You use a non-8bit native charset. " %s+%
 #             "This may cause serious problems. Consider switching to UTF-8.")
 #       else
@@ -86,11 +90,12 @@ stri_info <- function(short=FALSE) {
    else {
       locale <- info$Locale$Name
       charset <- info$Charset.native$Name.friendly
-      return(sprintf("stringi_%s (%s.%s; ICU4C %s [%s]; Unicode %s)",
+      return(sprintf("stringi_%s (%s.%s; ICU4C %s [%s%s]; Unicode %s)",
          as.character(packageVersion("stringi")),
          locale, charset,
          info$ICU.version,
          if (info$ICU.system) "system" else "bundle",
+         if (info$ICU.UTF8) "#U_CHARSET_IS_UTF8" else "",
          info$Unicode.version
       ))
    }
