@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' package for R.
- * Copyright (C) 2013-2016, Marek Gagolewski and Bartek Tartanus
+ * Copyright (c) 2013-2017, Marek Gagolewski and other contributors.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -225,7 +225,7 @@ SEXP stri_extract_all_charclass(SEXP str, SEXP pattern, SEXP merge, SEXP simplif
       StriContainerCharClass::locateAll(
          occurrences, &pattern_cont.get(i),
          str_cur_s, str_cur_n, merge_cur,
-         false /* byte-based indices */
+         false /* byte-based indexes */
       );
 
       R_len_t noccurrences = (R_len_t)occurrences.size();
